@@ -58,7 +58,7 @@ public class ScalarVMTest extends TestCase {
 
   private double executeLispExpr(String expr, double x, double y) {
     compileExpr((new ScalarLisp()).getAsXML(expr));
-    return scalarVM.execute(x, y, ScalarVM.epsilon);
+    return scalarVM.execute(x, y, ScalarVM.epsilon, 1.0, 1.0);
   }
 
   private String trimLines(String expr) {
@@ -116,7 +116,7 @@ public class ScalarVMTest extends TestCase {
 
   public void ignore_testExecute1() {
     ignore_testCompile1();
-    assertEquals(-0.3, scalarVM.execute(1.0, -1.0, ScalarVM.epsilon), ScalarVM.epsilon);
+    assertEquals(-0.3, scalarVM.execute(1.0, -1.0, ScalarVM.epsilon, 1.0, 1.0), ScalarVM.epsilon);
   }
 
   String expr2 =
@@ -162,7 +162,7 @@ public class ScalarVMTest extends TestCase {
 
   public void ignore_testExecute2() {
     compileExpr(expr2);
-    assertEquals(0.75, scalarVM.execute(2.0, 1.0, ScalarVM.epsilon), ScalarVM.epsilon);
+    assertEquals(0.75, scalarVM.execute(2.0, 1.0, ScalarVM.epsilon, 1.0, 1.0), ScalarVM.epsilon);
   }
 
   String exprIfPositive =
@@ -195,7 +195,7 @@ public class ScalarVMTest extends TestCase {
 
   public void ignore_testExecuteIfPositive() {
     compileExpr(exprIfPositive);
-    assertEquals(0.3, scalarVM.execute(0.2, ScalarVM.epsilon, ScalarVM.epsilon), ScalarVM.epsilon);
+    assertEquals(0.3, scalarVM.execute(0.2, ScalarVM.epsilon, ScalarVM.epsilon, 1.0, 1.0), ScalarVM.epsilon);
   }
 
   String exprNoise =
@@ -224,7 +224,7 @@ public class ScalarVMTest extends TestCase {
 
   public void ignore_testExecuteNoise() {
     compileExpr(exprNoise);
-    assertEquals(0.18026221874439646, scalarVM.execute(0.2, 0.1, ScalarVM.epsilon), ScalarVM.epsilon);
+    assertEquals(0.18026221874439646, scalarVM.execute(0.2, 0.1, ScalarVM.epsilon, 1.0, 1.0), ScalarVM.epsilon);
   }
 
   public void testGetAsXML() {
@@ -341,12 +341,12 @@ public class ScalarVMTest extends TestCase {
     ScalarExprGene scalarExprGene = entity.getScalarExpression().getChromosome().getScalarExpression();
     scalarVM.compile(scalarExprGene);
     for (int i = 0; i < 100; ++i) {
-      assertEquals(-0.3, scalarVM.execute(1.0, 2.0, ScalarVM.epsilon), ScalarVM.epsilon);
+      assertEquals(-0.3, scalarVM.execute(1.0, 2.0, ScalarVM.epsilon, 1.0, 1.0), ScalarVM.epsilon);
     }
     long start = System.currentTimeMillis();
     final int rounds = 1000000;
     for (int ix = 0; ix < rounds; ++ix) {
-      scalarVM.execute(1.0, 2.0, ScalarVM.epsilon);
+      scalarVM.execute(1.0, 2.0, ScalarVM.epsilon, 1.0, 1.0);
     }
     long done = System.currentTimeMillis() - start;
     System.out.println((1000.0 / (double)done) + " mips");
