@@ -598,7 +598,7 @@ public class ExportWizard extends javax.swing.JFrame {
       EntityType entity = soupFactory.createEntity(typeName, image);
       switch (exportState.exportType) {
         case Gateway.BITMAP_FILE :
-           (new BitmapFileEngine(chromosome, calculationName, colorator, exportState)).start();
+           (new BitmapFileEngine(chromosome, calculationName, colorator, exportState)).start((evt.getModifiers() & java.awt.Event.SHIFT_MASK) == java.awt.Event.SHIFT_MASK);
           break;
         case Gateway.GENOMEDB :
        // TODO WEB database
