@@ -241,12 +241,12 @@ public class SoupFactory {
       else if (image instanceof VectorExpressionImage) {
         newChromosome = kandid.soup.genetic.vectorvm.Randomizer.create();
       }
-      else if (image instanceof VoronoiImage) {
-        newChromosome = kandid.soup.genetic.voronoi.Randomizer.create();
-      }
-      else if (image instanceof VoronoiTransparentImage) {
-        newChromosome = kandid.soup.genetic.voronoi.RandomizerTransparent.create();
-      }
+//      else if (image instanceof VoronoiImage) {
+//        newChromosome = kandid.soup.genetic.voronoi.Randomizer.create();
+//      }
+//      else if (image instanceof VoronoiTransparentImage) {
+//        newChromosome = kandid.soup.genetic.voronoi.RandomizerTransparent.create();
+//      }
       else {
   
         // create chromosome
@@ -426,12 +426,12 @@ public class SoupFactory {
       else if (chromosome instanceof VectorExpressionChromosome) {
         newChromosome = kandid.soup.genetic.vectorvm.Cloner.deepclone((VectorExpressionChromosome) chromosome);
       }
-      else if (chromosome instanceof VoronoiChromosome) {
-        newChromosome = kandid.soup.genetic.voronoi.Cloner.deepclone((VoronoiChromosome) chromosome);
-      }
-      else if (chromosome instanceof VoronoiTransparentChromosome) {
-        newChromosome = kandid.soup.genetic.voronoi.ClonerTransparent.deepclone((VoronoiTransparentChromosome) chromosome);
-      }
+//      else if (chromosome instanceof VoronoiChromosome) {
+//        newChromosome = kandid.soup.genetic.voronoi.Cloner.deepclone((VoronoiChromosome) chromosome);
+//      }
+//      else if (chromosome instanceof VoronoiTransparentChromosome) {
+//        newChromosome = kandid.soup.genetic.voronoi.ClonerTransparent.deepclone((VoronoiTransparentChromosome) chromosome);
+//      }
       else {
         // find clone method
         Class[] signatureTypes = new Class[1];
@@ -527,14 +527,14 @@ public class SoupFactory {
         assert chromosome2 instanceof VectorExpressionChromosome;
         newChromosome = kandid.soup.genetic.vectorvm.Merger.merge(env, (VectorExpressionChromosome)chromosome1, (VectorExpressionChromosome)chromosome2);
       }
-      else if (chromosome1 instanceof VoronoiChromosome) {
-        assert chromosome2 instanceof VoronoiChromosome;
-        newChromosome = kandid.soup.genetic.voronoi.Merger.merge(env, (VoronoiChromosome)chromosome1, (VoronoiChromosome)chromosome2);
-      }
-      else if (chromosome1 instanceof VoronoiTransparentChromosome) {
-        assert chromosome2 instanceof VoronoiTransparentChromosome;
-        newChromosome = kandid.soup.genetic.voronoi.MergerTransparent.merge(env, (VoronoiTransparentChromosome)chromosome1, (VoronoiTransparentChromosome)chromosome2);
-      }
+//      else if (chromosome1 instanceof VoronoiChromosome) {
+//        assert chromosome2 instanceof VoronoiChromosome;
+//        newChromosome = kandid.soup.genetic.voronoi.Merger.merge(env, (VoronoiChromosome)chromosome1, (VoronoiChromosome)chromosome2);
+//      }
+//      else if (chromosome1 instanceof VoronoiTransparentChromosome) {
+//        assert chromosome2 instanceof VoronoiTransparentChromosome;
+//        newChromosome = kandid.soup.genetic.voronoi.MergerTransparent.merge(env, (VoronoiTransparentChromosome)chromosome1, (VoronoiTransparentChromosome)chromosome2);
+//      }
       else {
         // find merge method
         Class[] signatureTypes = new Class[3];
@@ -575,12 +575,12 @@ public class SoupFactory {
       else if (chromosome instanceof VectorExpressionChromosome) {
         mutationCounter = kandid.soup.genetic.vectorvm.Mutator.mutate(env, (VectorExpressionChromosome) chromosome);
       }
-      else if (chromosome instanceof VoronoiChromosome) {
-        mutationCounter = kandid.soup.genetic.voronoi.Mutator.mutate(env, (VoronoiChromosome) chromosome);
-      }
-      else if (chromosome instanceof VoronoiTransparentChromosome) {
-        mutationCounter = kandid.soup.genetic.voronoi.MutatorTransparent.mutate(env, (VoronoiTransparentChromosome) chromosome);
-      }
+//      else if (chromosome instanceof VoronoiChromosome) {
+//        mutationCounter = kandid.soup.genetic.voronoi.Mutator.mutate(env, (VoronoiChromosome) chromosome);
+//      }
+//      else if (chromosome instanceof VoronoiTransparentChromosome) {
+//        mutationCounter = kandid.soup.genetic.voronoi.MutatorTransparent.mutate(env, (VoronoiTransparentChromosome) chromosome);
+//      }
       else {
         // find mutate method
         Class[] signatureTypes = new Class[2];
@@ -1325,10 +1325,12 @@ public class SoupFactory {
     ChromosomeType chromosomeType = null;
     try {
       ImageType image = getImage(entity);
+      if(image != null) {
       // find getChromosome method
       Method getChromosome = image.getClass().getMethod("getChromosome", (Class<?>[])null);
       // get chromosome
       chromosomeType = (ChromosomeType)getChromosome.invoke(image, (Object[])null);
+      }
     } catch (Exception exc) {
       Debug.stackTrace(exc);
     }
@@ -1345,10 +1347,12 @@ public class SoupFactory {
     String calculationName = null;
     try {
       ImageType image = getImage(entity);
-      // find getCalculationName method
-      Method getCalculationNameMethod = image.getClass().getMethod("getCalculationName", (Class<?>[])null);
-      // get colorator name
-      calculationName = (String)getCalculationNameMethod.invoke(image, (Object[])null);
+      if(image != null) {
+        // find getCalculationName method
+        Method getCalculationNameMethod = image.getClass().getMethod("getCalculationName", (Class<?>[])null);
+        // get colorator name
+        calculationName = (String)getCalculationNameMethod.invoke(image, (Object[])null);
+      }
     } catch (Exception exc) {
       Debug.stackTrace(exc);
     }
